import { BedrockModel } from './bedrock-model';

export type ClaudeMessageContent = {
    type: 'text' | 'image';
    text?: string;
    source?: {
        type: 'base64';
        media_type: 'image/png' | 'image/jpeg';
        data: string;
    };
};

export type ClaudeMessage = {
    role: 'user' | 'assistant';
    content: ClaudeMessageContent[];
};

export type ClaudeThinkingParams = {
    enabled: boolean;
    budgetTokens: number;
};

export type ClaudeResponseContent = {
    type: 'text' | 'thinking';
    thinking?: string;
    text?: string;
};

export type ClaudeResponse = {
    usage: {
        inputTokens: number;
        outputTokens: number;
    };
    content: ClaudeResponseContent[];
};


/**
 * The ClaudeApi class provides an interface to interact with the Claude AI model
 * hosted on the Bedrock platform. It allows invocation of the model using various
 * parameters for customization.
 */
export class ClaudeApi {

    /**
     * Constructs an instance of the class with the specified credentials, region, and model configurations.
     *
     * @param {string} accessKeyId - The access key ID for authentication.
     * @param {string} secretAccessKey - The secret access key for authentication.
     * @param {string} region - The AWS region where the resources are located.
     * @param {BedrockModel} model - The model configuration to be used.
     */
    constructor(
        accessKeyId: string,
        secretAccessKey: string,
        region: string,
        model: BedrockModel,
    );

    /**
     * Invokes the method to process messages and generate a response based on the provided parameters.
     *
     * @param {ClaudeMessage[]} messages - An array of message objects to be processed.
     * @param {number} [temperature] - An optional parameter that controls the randomness of the output (default is undefined).
     * @param {number} [maxTokens] - An optional parameter specifying the maximum number of tokens for the response (default is undefined).
     * @param {string} [system] - An optional parameter specifying the system or context for the invocation (default is undefined).
     * @param {ClaudeThinkingParams} [thinking] - An optional parameter providing advanced configurations or parameters for processing (default is undefined).
     * @return {Promise<ClaudeResponse>} A promise that resolves to the generated response of type ClaudeResponse.
     */
    public invoke(
        messages: ClaudeMessage[],
        temperature?: number,
        maxTokens?: number,
        system?: string,
        thinking?: ClaudeThinkingParams,
    ): Promise<ClaudeResponse>;
}
