import { BedrockModel } from './bedrock-model';

export type DeepSeekContent = {
    text?: string;
};

export type DeepSeekMessage = {
    role?: 'user' | 'assistant';
    content: DeepSeekContent[];
};

export type DeepSeekResponseContent = {
    text?: string;
};

export type DeepSeekResponse = {
    usage: {
        inputTokens: number;
        outputTokens: number;
    };
    content: DeepSeekResponseContent[];
};

/**
 * DeepSeekApi is a class designed to interact with a Deep Seek service API.
 * This class provides methods to send messages and retrieve responses by leveraging
 * a specified language model hosted on the platform.
 *
 * @class
 */
export class DeepSeekApi {
    /**
     * Creates a new instance of the class with the provided credentials, region, and model configuration.
     *
     * @param {string} accessKeyId - The AWS access key ID used for authentication.
     * @param {string} secretAccessKey - The AWS secret access key used for authentication.
     * @param {string} region - The AWS region where the service operates.
     * @param {BedrockModel} model - The Bedrock model configuration to be used.
     */
    constructor(
        accessKeyId: string,
        secretAccessKey: string,
        region: string,
        model: BedrockModel,
    );

    /**
     * Invokes the function with specified parameters to process an array of messages and generate a response.
     *
     * @param {DeepSeekMessage[]} messages - An array of message objects to process.
     * @param {number} [temperature] - Optional parameter to control the randomness of the response generation. Higher values increase randomness.
     * @param {number} [maxTokens] - Optional maximum number of tokens allowed in the response.
     * @param {number} [topP] - Optional parameter that controls nucleus sampling for response generation.
     * @param {string} [systemPrompt] - Optional system-level instruction to guide response generation.
     *
     * @return {Promise<DeepSeekResponse>} A promise that resolves to a DeepSeekResponse object containing the generated result.
     */
    public invoke(
        messages: DeepSeekMessage[],
        temperature?: number,
        maxTokens?: number,
        topP?: number,
        systemPrompt?: string,
    ): Promise<DeepSeekResponse>;
}
