import { BedrockModel } from './bedrock-model';

export type NovaContent = {
    text?: string;
    image?: {
        format: 'png' | 'jpeg' | 'gif' | 'webp';
        source: { bytes: Uint8Array };
    };
};

export type NovaMessage = {
    role?: 'user' | 'assistant';
    content: NovaContent[];
};

export type NovaResponseContent = {
    text?: string;
};

export type NovaResponse = {
    usage: {
        inputTokens: number;
        outputTokens: number;
    };
    content: NovaResponseContent[];
};

/**
 * Represents the NovaApi class, which is used to interact with the Nova API.
 * It provides methods to invoke API requests for processing messages using a specified model.
 */
export class NovaApi {
    /**
     * Constructs an instance of the class with the provided configuration parameters.
     *
     * @param {string} accessKeyId - The access key ID used for authentication.
     * @param {string} secretAccessKey - The secret access key used for authentication.
     * @param {string} region - The specific region to connect to for the service.
     * @param {BedrockModel} model - The model configuration used for the instance.
     */
    constructor(
        accessKeyId: string,
        secretAccessKey: string,
        region: string,
        model: BedrockModel,
    );

    /**
     * Invokes the Nova AI system with the given parameters to process messages and generate a response.
     *
     * @param {NovaMessage[]} messages - An array of messages to process.
     * @param {number} [temperature] - Controls the randomness of the response. Higher values result in more diverse outputs, while lower values make the output more deterministic.
     * @param {number} [maxTokens] - The maximum number of tokens to generate in the response.
     * @param {number} [topP] - Controls nucleus sampling, where the model considers the results of tokens with cumulative probability up to this value. Lower values make the output more focused.
     * @param {string} [systemPrompt] - Optional system-level prompt to guide the behavior of the AI system.
     * @return {Promise<NovaResponse>} - A promise that resolves to the response generated by Nova.
     */
    public invoke(
        messages: NovaMessage[],
        temperature?: number,
        maxTokens?: number,
        topP?: number,
        systemPrompt?: string
    ): Promise<NovaResponse>;
}